[RFA]: yyparse langhook

Neil Booth neil@daikokuya.demon.co.uk
Sun Mar 17 07:22:00 GMT 2002


Also gets rid of yyparse_1 kludge.  Bootstrapped and regtested all
except ada.  OK to commit?

Neil.

	* c-common.h (yyparse, c_common_parse_file): New.
	* c-lang.c: Include c-common.h.
	(LANG_HOOKS_PARSE_FILE): Redefine.
	* c-lex.c: Include c-common.h.
	(yyparse): Rename c_common_parse_file.  Call yyparse.
	* c-parse.in (yyparse): Remove macro.
	* c-tree.h (yyparse_1): Remove.
	* langhooks-def.h (LANG_HOOKS_PARSE_FILE): New.
	(LANG_HOOKS_INITIALIZER): Update.
	* langhooks.h (struct lang_hoooks): New hook parse_file.
	* toplev.c (compile_file): Use parse_file hook.
	* tree.h (yyparse): Remove.
ada:
	* misc.c (LANG_HOOKS_PARSE_FILE): Redefine.
	(yyparse): Rename gnat_parse_file.
cp:
	* cp-lang.c (LANG_HOOKS_PARSE_FILE): Redefine.
	* parse.y (yyparse): Remove macro.
f:
	* com.c (LANG_HOOKS_PARSE_FILE): Redefine.
	* com.h (ffe_parse_file): New.
	* parse.c (NAME_OF_STDIN): Remove.
	(yyparse): Rename ffe_parse_file.
java:
	* java-tree.h (java_parse_file): New.
	* jcf-parse.c (yyparse): Rename java_parse_file.
	* lang.c (LANG_HOOKS_PARSE_FILE): Redefine.
objc:
	* objc-lang.c (LANG_HOOKS_PARSE_FILE): Redefine.

============================================================
Index: gcc/c-common.h
--- gcc/c-common.h	2002/03/15 20:08:25	1.118
+++ gcc/c-common.h	2002/03/16 23:18:05
@@ -325,7 +325,7 @@ extern void (*lang_expand_function_end) 
    noreturn attribute.  */
 extern int (*lang_missing_noreturn_ok_p)	PARAMS ((tree));
 
-
+extern int yyparse				PARAMS ((void));
 extern stmt_tree current_stmt_tree              PARAMS ((void));
 extern tree *current_scope_stmt_stack           PARAMS ((void));
 extern void begin_stmt_tree                     PARAMS ((tree *));
@@ -552,6 +552,7 @@ extern void c_common_init_options		PARAM
 extern void c_common_post_options		PARAMS ((void));
 extern const char *c_common_init		PARAMS ((const char *));
 extern void c_common_finish			PARAMS ((void));
+extern void c_common_parse_file			PARAMS ((void));
 extern HOST_WIDE_INT c_common_get_alias_set	PARAMS ((tree));
 extern bool c_promoting_integer_type_p		PARAMS ((tree));
 extern int self_promoting_args_p		PARAMS ((tree));
============================================================
Index: gcc/c-lang.c
--- gcc/c-lang.c	2002/03/13 01:42:30	1.76
+++ gcc/c-lang.c	2002/03/16 23:18:05
@@ -24,6 +24,7 @@ Software Foundation, 59 Temple Place - S
 #include "system.h"
 #include "tree.h"
 #include "c-tree.h"
+#include "c-common.h"
 #include "langhooks.h"
 #include "langhooks-def.h"
 
@@ -49,6 +50,8 @@ static void c_post_options PARAMS ((void
 #define LANG_HOOKS_GET_ALIAS_SET c_common_get_alias_set
 #undef LANG_HOOKS_SAFE_FROM_P
 #define LANG_HOOKS_SAFE_FROM_P c_safe_from_p
+#undef LANG_HOOKS_PARSE_FILE
+#define LANG_HOOKS_PARSE_FILE c_common_parse_file
 #undef LANG_HOOKS_STATICP
 #define LANG_HOOKS_STATICP c_staticp
 #undef LANG_HOOKS_PRINT_IDENTIFIER
============================================================
Index: gcc/c-lex.c
--- gcc/c-lex.c	2002/03/12 22:36:54	1.166
+++ gcc/c-lex.c	2002/03/16 23:18:15
@@ -29,6 +29,7 @@ Software Foundation, 59 Temple Place - S
 #include "output.h"
 #include "c-lex.h"
 #include "c-tree.h"
+#include "c-common.h"
 #include "flags.h"
 #include "timevar.h"
 #include "cpplib.h"
@@ -155,13 +156,13 @@ init_c_lex (filename)
    Also, make sure the start_source_file debug hook gets called for
    the primary source file.  */
 
-int
-yyparse()
+void
+c_common_parse_file ()
 {
   (*debug_hooks->start_source_file) (lineno, input_filename);
   cpp_finish_options (parse_in);
 
-  return yyparse_1();
+  yyparse ();
 }
 
 struct c_fileinfo *
============================================================
Index: gcc/c-parse.in
--- gcc/c-parse.in	2002/02/28 18:51:14	1.129
+++ gcc/c-parse.in	2002/03/16 23:18:20
@@ -64,9 +64,6 @@ end ifobjc
 
 /* Cause the "yydebug" variable to be defined.  */
 #define YYDEBUG 1
-
-/* Rename the "yyparse" function so that we can override it elsewhere.  */
-#define yyparse yyparse_1
 %}
 
 %start program
============================================================
Index: gcc/c-tree.h
--- gcc/c-tree.h	2002/02/28 07:39:24	1.83
+++ gcc/c-tree.h	2002/03/16 23:18:22
@@ -161,7 +161,6 @@ extern tree lookup_objc_ivar			PARAMS ((
 /* in c-parse.in */
 extern void c_parse_init			PARAMS ((void));
 extern void c_set_yydebug			PARAMS ((int));
-extern int yyparse_1				PARAMS ((void));
 
 /* in c-aux-info.c */
 extern void gen_aux_info_record                 PARAMS ((tree, int, int, int));
============================================================
Index: gcc/langhooks-def.h
--- gcc/langhooks-def.h	2002/03/08 19:20:47	1.10
+++ gcc/langhooks-def.h	2002/03/16 23:18:22
@@ -68,6 +68,7 @@ void lhd_tree_inlining_end_inlining		PAR
 #define LANG_HOOKS_IDENTIFIER_SIZE	sizeof (struct lang_identifier)
 #define LANG_HOOKS_INIT			lhd_do_nothing
 #define LANG_HOOKS_FINISH		lhd_do_nothing
+#define LANG_HOOKS_PARSE_FILE		lhd_do_nothing
 #define LANG_HOOKS_CLEAR_BINDING_STACK	lhd_clear_binding_stack
 #define LANG_HOOKS_INIT_OPTIONS		lhd_do_nothing
 #define LANG_HOOKS_DECODE_OPTION	lhd_decode_option
@@ -141,6 +142,7 @@ int lhd_tree_dump_type_quals			PARAMS ((
   LANG_HOOKS_POST_OPTIONS, \
   LANG_HOOKS_INIT, \
   LANG_HOOKS_FINISH, \
+  LANG_HOOKS_PARSE_FILE, \
   LANG_HOOKS_CLEAR_BINDING_STACK, \
   LANG_HOOKS_GET_ALIAS_SET, \
   LANG_HOOKS_EXPAND_CONSTANT, \
============================================================
Index: gcc/langhooks.h
--- gcc/langhooks.h	2002/03/08 19:20:47	1.17
+++ gcc/langhooks.h	2002/03/16 23:18:23
@@ -104,6 +104,9 @@ struct lang_hooks
   /* Called at the end of compilation, as a finalizer.  */
   void (*finish) PARAMS ((void));
 
+  /* Parses the entire file.  */
+  void (*parse_file) PARAMS ((void));
+
   /* Called immediately after parsing to clear the binding stack.  */
   void (*clear_binding_stack) PARAMS ((void));
 
============================================================
Index: gcc/tree.h
--- gcc/tree.h	2002/03/13 01:42:32	1.314
+++ gcc/tree.h	2002/03/16 23:18:45
@@ -2859,8 +2859,6 @@ extern tree fold_builtin		PARAMS ((tree)
 
 /* The language front-end must define these functions.  */
 
-/* Function called with no arguments to parse and compile the input.  */
-extern int yyparse				PARAMS ((void));
 /* Functions for processing symbol declarations.  */
 /* Function to enter a new lexical scope.
    Takes one argument: always zero when called from outside the front end.  */
============================================================
Index: gcc/ada/misc.c
--- gcc/ada/misc.c	2002/03/14 10:59:31	1.22
+++ gcc/ada/misc.c	2002/03/16 23:18:48
@@ -85,6 +85,7 @@ static void gnat_print_type		PARAMS ((FI
 static const char *gnat_printable_name	PARAMS  ((tree, int));
 static tree gnat_eh_runtime_type	PARAMS ((tree));
 static int gnat_eh_type_covers		PARAMS ((tree, tree));
+static void gnat_parse_file		PARAMS ((void));
 
 /* Structure giving our language-specific hooks.  */
 
@@ -98,6 +99,8 @@ static int gnat_eh_type_covers		PARAMS (
 #define LANG_HOOKS_INIT_OPTIONS		gnat_init_options
 #undef  LANG_HOOKS_DECODE_OPTION
 #define LANG_HOOKS_DECODE_OPTION	gnat_decode_option
+#undef LANG_HOOKS_PARSE_FILE
+#define LANG_HOOKS_PARSE_FILE		gnat_parse_file
 #undef LANG_HOOKS_HONOR_READONLY
 #define LANG_HOOKS_HONOR_READONLY	1
 #undef LANG_HOOKS_GET_ALIAS_SET
@@ -167,11 +170,10 @@ extern void __gnat_initialize	PARAMS((vo
 extern void adainit		PARAMS((void));
 extern void _ada_gnat1drv	PARAMS((void));
 
-/* For most front-ends, this is the parser for the language.  For us, we
-   process the GNAT tree.  */
+/* The parser for the language.  For us, we process the GNAT tree.  */
 
-int
-yyparse ()
+static void
+gnat_parse_file ()
 {
   /* call the target specific initializations */
   __gnat_initialize();
@@ -183,8 +185,6 @@ yyparse ()
 
   /* Call the front end */
   _ada_gnat1drv ();
-
-  return 0;
 }
 
 /* Decode all the language specific options that cannot be decoded by GCC.
============================================================
Index: gcc/cp/cp-lang.c
--- gcc/cp/cp-lang.c	2002/03/13 01:42:39	1.13
+++ gcc/cp/cp-lang.c	2002/03/16 23:18:48
@@ -51,6 +51,8 @@ static bool ok_to_generate_alias_set_for
 #define LANG_HOOKS_EXPAND_CONSTANT cplus_expand_constant
 #undef LANG_HOOKS_SAFE_FROM_P
 #define LANG_HOOKS_SAFE_FROM_P c_safe_from_p
+#undef LANG_HOOKS_PARSE_FILE
+#define LANG_HOOKS_PARSE_FILE c_common_parse_file
 #undef LANG_HOOKS_DUP_LANG_SPECIFIC_DECL
 #define LANG_HOOKS_DUP_LANG_SPECIFIC_DECL cxx_dup_lang_specific_decl
 #undef LANG_HOOKS_UNSAVE_EXPR_NOW
============================================================
Index: gcc/cp/parse.y
--- gcc/cp/parse.y	2002/03/02 19:51:56	1.249
+++ gcc/cp/parse.y	2002/03/16 23:18:56
@@ -228,9 +228,6 @@ cp_parse_init ()
   ggc_add_tree_root (&current_enum_type, 1);
   ggc_add_tree_root (&saved_scopes, 1);
 }
-
-/* Rename the "yyparse" function so that we can override it elsewhere.  */
-#define yyparse yyparse_1
 %}
 
 %start program
============================================================
Index: gcc/f/com.c
--- gcc/f/com.c	2002/03/13 01:42:41	1.157
+++ gcc/f/com.c	2002/03/16 23:19:29
@@ -13928,7 +13928,7 @@ start_decl (tree decl, bool is_top_level
 
    Returns 1 on success.  If the DECLARATOR is not suitable for a function
    (it defines a datum instead), we return 0, which tells
-   yyparse to report a parse error.
+   ffe_parse_file to report a parse error.
 
    NESTED is nonzero for a function nested within another function.  */
 
@@ -14211,6 +14211,8 @@ static void ffe_print_identifier PARAMS 
 #define LANG_HOOKS_INIT_OPTIONS		ffe_init_options
 #undef  LANG_HOOKS_DECODE_OPTION
 #define LANG_HOOKS_DECODE_OPTION	ffe_decode_option
+#undef  LANG_HOOKS_PARSE_FILE
+#define LANG_HOOKS_PARSE_FILE		ffe_parse_file
 #undef  LANG_HOOKS_PRINT_IDENTIFIER
 #define LANG_HOOKS_PRINT_IDENTIFIER	ffe_print_identifier
 
============================================================
Index: gcc/f/com.h
--- gcc/f/com.h	2001/10/17 22:34:51	1.22
+++ gcc/f/com.h	2002/03/16 23:19:30
@@ -265,6 +265,7 @@ tree ffecom_truth_value (tree expr);
 tree ffecom_truth_value_invert (tree expr);
 tree ffecom_type_expr (ffebld expr);
 tree ffecom_which_entrypoint_decl (void);
+void ffe_parse_file ();
 
 /* Define macros. */
 
============================================================
Index: gcc/f/parse.c
--- gcc/f/parse.c	2001/10/17 22:34:52	1.10
+++ gcc/f/parse.c	2002/03/16 23:19:30
@@ -26,12 +26,10 @@ the Free Software Foundation, 59 Temple 
 #include "version.h"
 #include "flags.h"
 
-#define NAME_OF_STDIN "<stdin>"
-
 extern FILE *finput;
 
-int
-yyparse ()
+void
+ffe_parse_file ()
 {
   ffewhereFile wf;
 
@@ -46,6 +44,4 @@ yyparse ()
   ffe_file (wf, finput);
 
   ffecom_finish_compile ();
-
-  return 0;
 }
============================================================
Index: gcc/java/java-tree.h
--- gcc/java/java-tree.h	2002/02/28 11:40:28	1.138
+++ gcc/java/java-tree.h	2002/03/16 23:19:35
@@ -1037,6 +1037,7 @@ struct lang_type
 #define JCF_u2 unsigned short
 
 extern void java_set_yydebug PARAMS ((int));
+extern void java_parse_file PARAMS ((void));
 extern void add_assume_compiled PARAMS ((const char *, int));
 extern tree lookup_class PARAMS ((tree));
 extern tree lookup_java_constructor PARAMS ((tree, tree));
============================================================
Index: gcc/java/jcf-parse.c
--- gcc/java/jcf-parse.c	2002/03/15 18:00:22	1.109
+++ gcc/java/jcf-parse.c	2002/03/16 23:19:37
@@ -913,8 +913,8 @@ predefined_filename_p (node)
   return 0;
 }
 
-int
-yyparse ()
+void
+java_parse_file ()
 {
   int filename_count = 0;
   char *list, *next;
@@ -1054,7 +1054,7 @@ yyparse ()
       resource_filename = IDENTIFIER_POINTER (TREE_VALUE (current_file_list));
       compile_resource_file (resource_name, resource_filename);
 
-      return 0;
+      return;
     }
 
   current_jcf = main_jcf;
@@ -1156,7 +1156,6 @@ yyparse ()
       if (flag_indirect_dispatch)
 	emit_offset_symbol_table ();
     }
-  return 0;
 }
 
 /* Process all class entries found in the zip file.  */
============================================================
Index: gcc/java/lang.c
--- gcc/java/lang.c	2002/03/13 01:42:42	1.89
+++ gcc/java/lang.c	2002/03/16 23:19:39
@@ -221,6 +221,8 @@ static int dependency_tracking = 0;
 #define LANG_HOOKS_DECODE_OPTION java_decode_option
 #undef LANG_HOOKS_SET_YYDEBUG
 #define LANG_HOOKS_SET_YYDEBUG java_set_yydebug
+#undef LANG_HOOKS_PARSE_FILE
+#define LANG_HOOKS_PARSE_FILE java_parse_file
 #undef LANG_HOOKS_DUP_LANG_SPECIFIC_DECL
 #define LANG_HOOKS_DUP_LANG_SPECIFIC_DECL java_dup_lang_specific_decl
 
============================================================
Index: gcc/objc/objc-lang.c
--- gcc/objc/objc-lang.c	2002/03/13 01:42:43	1.4
+++ gcc/objc/objc-lang.c	2002/03/16 23:19:39
@@ -44,6 +44,8 @@ static void objc_post_options           
 #define LANG_HOOKS_DECODE_OPTION objc_decode_option
 #undef LANG_HOOKS_POST_OPTIONS
 #define LANG_HOOKS_POST_OPTIONS objc_post_options
+#undef LANG_HOOKS_PARSE_FILE
+#define LANG_HOOKS_PARSE_FILE c_common_parse_file
 #undef LANG_HOOKS_STATICP
 #define LANG_HOOKS_STATICP c_staticp
 #undef LANG_HOOKS_DUP_LANG_SPECIFIC_DECL



More information about the Gcc-patches mailing list
Index: gcc/toplev.c
--- gcc/toplev.c	2002/03/15 09:54:39	1.596
+++ gcc/toplev.c	2002/03/16 23:18:35
@@ -2106,9 +2106,9 @@ compile_file ()
 
   timevar_push (TV_PARSE);
 
-  /* Call the parser, which parses the entire file
-     (calling rest_of_compilation for each function).  */
-  yyparse ();
+  /* Call the parser, which parses the entire file (calling
+     rest_of_compilation for each function).  */
+  (*lang_hooks.parse_file) ();
 
   /* In case there were missing block closers,
      get us back to the global binding level.  */
@@ -2116,7 +2116,6 @@ compile_file ()
 
   /* Compilation is now finished except for writing
      what's left of the symbol table output.  */
-
   timevar_pop (TV_PARSE);
 
   if (flag_syntax_only)
@@ -2339,7 +2338,7 @@ rest_of_type_compilation (type, toplev)
   timevar_pop (TV_SYMOUT);
 }
 
 /* This is called from finish_function (within yyparse)
    after each top-level definition is parsed.
    It is supposed to compile that function or variable
    and output the assembler code for it.
@@ -2339,7 +2338,7 @@ rest_of_type_compilation (type, toplev)
 }
 
-/* This is called from finish_function (within yyparse)
+/* This is called from finish_function (within langhooks.parse_file)
    after each top-level definition is parsed.
    It is supposed to compile that function or variable
============================================================